AnimStateKey

Enum AnimStateKey 

pub enum AnimStateKey {
    Hover,
    Pressed,
    Disabled,
    Normal,
    Active,
}
One component of an AnimState

This represents the animation state of a widget. Animated images use this state to determine which image is used from a set of available images.

Variants



Hover

The mouse is hovering over the widget



Pressed

The mouse is pressed on a widget



Disabled

The widget is disabled



Normal

The widget has no special animation state.



Active

The widget is activated.